==> openshift-model-monitoring-5.10.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProbeSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec,io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecBuilder>{
  public ProbeSpecBuilder() {
    this(false);
  }
  public ProbeSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ProbeSpec(), validationEnabled);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProbeSpec(), validationEnabled);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec instance) {
    this(fluent, instance, false);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withBasicAuth(instance.getBasicAuth()); 
    fluent.withBearerTokenSecret(instance.getBearerTokenSecret()); 
    fluent.withInterval(instance.getInterval()); 
    fluent.withJobName(instance.getJobName()); 
    fluent.withModule(instance.getModule()); 
    fluent.withProber(instance.getProber()); 
    fluent.withScrapeTimeout(instance.getScrapeTimeout()); 
    fluent.withTargets(instance.getTargets()); 
    fluent.withTlsConfig(instance.getTlsConfig()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec instance) {
    this(instance,false);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withBasicAuth(instance.getBasicAuth()); 
    this.withBearerTokenSecret(instance.getBearerTokenSecret()); 
    this.withInterval(instance.getInterval()); 
    this.withJobName(instance.getJobName()); 
    this.withModule(instance.getModule()); 
    this.withProber(instance.getProber()); 
    this.withScrapeTimeout(instance.getScrapeTimeout()); 
    this.withTargets(instance.getTargets()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec build() {
    ProbeSpec buildable = new ProbeSpec(fluent.getBasicAuth(),fluent.getBearerTokenSecret(),fluent.getInterval(),fluent.getJobName(),fluent.getModule(),fluent.getProber(),fluent.getScrapeTimeout(),fluent.getTargets(),fluent.getTlsConfig());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProbeSpecBuilder that = (ProbeSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProbeSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec,io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecBuilder>{
  public ProbeSpecBuilder() {
    this(false);
  }
  public ProbeSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new ProbeSpec(), validationEnabled);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProbeSpec(), validationEnabled);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec instance) {
    this(fluent, instance, false);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAuthorization(instance.getAuthorization()); 
    fluent.withBasicAuth(instance.getBasicAuth()); 
    fluent.withBearerTokenSecret(instance.getBearerTokenSecret()); 
    fluent.withInterval(instance.getInterval()); 
    fluent.withJobName(instance.getJobName()); 
    fluent.withLabelLimit(instance.getLabelLimit()); 
    fluent.withLabelNameLengthLimit(instance.getLabelNameLengthLimit()); 
    fluent.withLabelValueLengthLimit(instance.getLabelValueLengthLimit()); 
    fluent.withMetricRelabelings(instance.getMetricRelabelings()); 
    fluent.withModule(instance.getModule()); 
    fluent.withOauth2(instance.getOauth2()); 
    fluent.withProber(instance.getProber()); 
    fluent.withSampleLimit(instance.getSampleLimit()); 
    fluent.withScrapeTimeout(instance.getScrapeTimeout()); 
    fluent.withTargetLimit(instance.getTargetLimit()); 
    fluent.withTargets(instance.getTargets()); 
    fluent.withTlsConfig(instance.getTlsConfig()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec instance) {
    this(instance,false);
  }
  public ProbeSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAuthorization(instance.getAuthorization()); 
    this.withBasicAuth(instance.getBasicAuth()); 
    this.withBearerTokenSecret(instance.getBearerTokenSecret()); 
    this.withInterval(instance.getInterval()); 
    this.withJobName(instance.getJobName()); 
    this.withLabelLimit(instance.getLabelLimit()); 
    this.withLabelNameLengthLimit(instance.getLabelNameLengthLimit()); 
    this.withLabelValueLengthLimit(instance.getLabelValueLengthLimit()); 
    this.withMetricRelabelings(instance.getMetricRelabelings()); 
    this.withModule(instance.getModule()); 
    this.withOauth2(instance.getOauth2()); 
    this.withProber(instance.getProber()); 
    this.withSampleLimit(instance.getSampleLimit()); 
    this.withScrapeTimeout(instance.getScrapeTimeout()); 
    this.withTargetLimit(instance.getTargetLimit()); 
    this.withTargets(instance.getTargets()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.ProbeSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeSpec build() {
    ProbeSpec buildable = new ProbeSpec(fluent.getAuthorization(),fluent.getBasicAuth(),fluent.getBearerTokenSecret(),fluent.getInterval(),fluent.getJobName(),fluent.getLabelLimit(),fluent.getLabelNameLengthLimit(),fluent.getLabelValueLengthLimit(),fluent.getMetricRelabelings(),fluent.getModule(),fluent.getOauth2(),fluent.getProber(),fluent.getSampleLimit(),fluent.getScrapeTimeout(),fluent.getTargetLimit(),fluent.getTargets(),fluent.getTlsConfig());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProbeSpecBuilder that = (ProbeSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
